/* Copyright 2022 Anri Dellal
 * SPDX-License-Identifier: MPL-2.0 */

@-moz-document regexp("about:preferences.*") {
    .sticky-container {
        display: flex;
    }

    #policies-container {
        display: none;
    }

    /* #sync page */
    .fxaMobilePromo {
        display: none;
    }

    @media (max-width: 700px) {
        :root, :host(.anonymous-content-host) {
            --page-main-content-width: calc(100vw - 60px);
        }

        .fxaSyncIllustration, .fxaProfileImage {
            display: none;
        }

        #mainPrefPane, #fxaContentWrapper {
            max-width: calc(100vw - 60px);
        }
    }
}
