/* Copyright 2022 Anri Dellal
 * SPDX-License-Identifier: MPL-2.0 */

@-moz-document url("about:addons"), url-prefix("about:addons") {
    :root {
        --section-width: min(664px, 100%) !important;
    }

    @media (max-width: 700px) {
        :root, :host(.anonymous-content-host) {
            --page-main-content-width: calc(100vw - 60px) !important;
        }

        .main-search .search-label {
            display: none;
        }

        #mainPrefPane, #fxaContentWrapper {
            max-width: calc(100vw - 60px);
        }

    }
}
